Name:           simbody
Version:        3.6.1
Release:        1%{?dist}
Summary:        Multi-body dynamics and physics library

License:        ASL 2.0
URL:            https://simtk.org/home/simbody
Source0:        https://github.com/simbody/simbody/archive/Simbody-%{version}/%{name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  lapack-devel
BuildRequires:  libXi-devel
BuildRequires:  libXmu-devel

%description
Simbody is a high-performance, open-source toolkit for science- and
engineering-quality simulation of articulated mechanisms, including
bio-mechanical structures such as human and animal skeletons, mechanical
systems like robots, vehicles, and machines, and anything else that can be
described as a set of rigid bodies interconnected by joints, influenced by
forces and motions, and restricted by constraints.

%package        visualizer
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    visualizer
The %{name}-visualizer package contains a visualizer that allows to watch the
system move.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%package        devel-doc
Summary:        Documentation for %{name}

%description    devel-doc
The %{name}-devel-doc package contains documentation for developing
applications with %{name}.

%prep
%autosetup -n simbody-Simbody-%{version}


%build
mkdir -p build
pushd build
%cmake \
  -DBUILD_EXAMPLES=OFF \
  -DBUILD_TESTING=ON \
  -DBUILD_VISUALIZER=ON \
  -DBUILD_DYNAMIC_LIBRARIES=ON \
  -DBUILD_STATIC_LIBRARIES=OFF \
  ..
%make_build
make doxygen
popd


%install
pushd build
%make_install
popd


%check
pushd build
ctest -j`nproc`
popd


%files
%license LICENSE.txt
%doc README.md
%{_libdir}/libSimTKcommon.so.3.6
%{_libdir}/libSimTKmath.so.3.6
%{_libdir}/libSimTKsimbody.so.3.6


%files devel
%{_includedir}/simbody
%{_libdir}/libSimTKcommon.so
%{_libdir}/libSimTKmath.so
%{_libdir}/libSimTKsimbody.so
%{_libdir}/cmake/simbody
%{_libdir}/pkgconfig/simbody.pc


%files devel-doc
%{_docdir}/simbody


%files visualizer
# The visualizer is in libexecdir because it sis typically called from another
# library, not by the user.
%{_libexecdir}/simbody/simbody-visualizer


%changelog
* Fri Nov 23 2018 Till Hofmann <thofmann@fedoraproject.org> - 3.6.1-1
- Initial package
